Info class

Holds the attributes of an output driver

Properties

byteFormat → int?
Specifies the preferred ordering of the sample bytes.
final
comment → String
Driver comment.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
A longer name for the driver.
final
priority → int?
A positive integer ranking how likely it is for this driver to be the default.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
A short identifier for the driver.
final
type → OutputType
The output type of the driver.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited