Libao class

Wraps the libao library.

Constructors

Libao.open([String? path])
Loads the libao library.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(Device device) → bool
Closes the audio device and frees the memory allocated by the device.
defaultDriverId() → int
Returns the ID number of the default live output driver.
driverId(String shortname) → int
Looks up the ID number for a driver based upon its short name. The ID number is need to open the driver or get info on it.
driverInfo(int id) → Info
Gets information about a particular driver.
driverInfoList() → List<Info>
Gets a list of information for all of the available drivers.
initialize() → void
Initializes the internal libao data structures and loads all of the available plugins.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFile(int driverId, String filename, {int bits = 16, int rate = 44100, int channels = 2, ByteFormat byteFormat = ByteFormat.little, String? matrix}) → Device
Open a file for audio output. The file format is determined by the audio driver used.
openLive(int driverId, {int bits = 16, int rate = 44100, int channels = 2, ByteFormat byteFormat = ByteFormat.little, String? matrix}) → Device
Open a live playback audio device for output.
play(Device device, Uint8List samples) → bool
Play a block of audio data to an open device. Samples are interleaved by channels.
shutdown() → void
unloads all of the plugins and deallocates any internal data structures the library has created. It should be called prior to program exit.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited